Maastricht Diffusion Toolbox
============================

.. image:: https://badge.fury.io/py/mdt.png
    :target: http://badge.fury.io/py/mdt

A diffusion toolkit for parallelized sampling and optimization of diffusion dMRI images.

* Free software: LGPL v3 license
* Full documentation: http://maastrichtdiffusiontoolbox.readthedocs.io
* Project home: https://github.com/cbclab/MDT
* Uses the `GitLab workflow <https://docs.gitlab.com/ee/workflow/gitlab_flow.html>`_
* Tags: diffusion, dMRI, MRI, optimization, parallel, opencl, python

Quick installation guide:

**Linux (Ubuntu)**

* ``sudo apt-get install python3 python3-pip python3-pyopencl python3-numpy python3-nibabel python3-pyqt5 python3-matplotlib python3-six python3-yaml python3-argcomplete libpng-dev libfreetype6-dev libxft-dev``
* ``sudo pip3 install MDT``


| **Windows**
| The installation on Windows is a little bit more complex and the following is only a quick reference guide. For complete instructions please view the `complete documentation <https://maastrichtdiffusiontoolbox.readthedocs.org>`_.

* Install MOT using the guide at https://mot.readthedocs.io
* Install the PyQt5 bindings
    * Use the `M-Labs PyQt5 package <https://anaconda.org/m-labs/pyqt5>`_
* Open a Anaconda shell and type: ``pip install MDT``


For more information and installation instructions, please see: https://maastrichtdiffusiontoolbox.readthedocs.org
